@@ -3,27 +3,34 @@ use 5.014;
 use warnings;
 use Carp qw(confess);
 
-$FASTX::Reader::VERSION = '0.01';
-#ABSTRACT: A lightweight FASTA and FASTQ parser
+$FASTX::Reader::VERSION = '0.02';
+
+#ABSTRACT: A lightweight FASTA and FASTQ reader based on Heng Li's parser, to retrieve name, comments*, sequence and quality* of each record. (* if any)
 
 
 
 
 sub new {
-    # INstantiate object
+    # Instantiate object
     my ($class, $args) = @_;
 
     my $self = {
         filename  => $args->{filename},
     };
 
-    # Check file readability
-    open my $fh,  '<:encoding(UTF-8)', $self->{filename} or confess "Unable to read file ", $self->{filename}, ": ", $!, "\n";
     my $object = bless $self, $class;
 
     # Initialize auxiliary array for getRead
     $object->{aux} = [undef];
-    $object->{fh} = $fh;
+
+    # Check if a filename was provided and not {{STDIN}}
+    if (defined $self->{filename} and $self->{filename} ne '{{STDIN}}') {
+      open my $fh,  '<:encoding(UTF-8)', $self->{filename} or confess "Unable to read file ", $self->{filename}, ": ", $!, "\n";
+      $object->{fh} = $fh;
+    } else {
+      $self->{fh} = \*STDIN;
+    }
+
     return $object;
 }
 
@@ -165,11 +172,11 @@ __END__
 
 =head1 NAME
 
-FASTX::Reader - A lightweight FASTA and FASTQ parser
+FASTX::Reader - A lightweight FASTA and FASTQ reader based on Heng Li's parser, to retrieve name, comments*, sequence and quality* of each record. (* if any)
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -194,6 +201,12 @@ readfq() method L<https://github.com/lh3/readfq>, packaged in an object oriented
 Initialize a new FASTX::Reader object passing 'filename' argument. Will open a filehandle
 stored as $object->{fh}.
 
+  my $seq_from_file = FASTX::Reader->({ filename => "$file" });
+
+To read from STDIN either pass C<{{STDIN}}> as filename, or don't pass a filename at all:
+
+  my $seq_from_stdin = FASTX::Reader->();
+
 =head2 getRead()
 
 Will return the next sequence in the FASTA / FASTQ file using Heng Li's implementation of the readfq() algorithm.
@@ -201,39 +214,66 @@ The returned object has these attributes:
 
 =over 4
 
-=item I<name>, header of the sequence (identifier)
+=item I<name>
 
-=item I<comment>, any string after the first whitespace in the header
+header of the sequence (identifier)
 
-=item I<seq>, actual sequence
+=item I<comment>
 
-=item I<qual>, quality if the file is FASTQ
+any string after the first whitespace in the header
+
+=item I<seq>
+
+actual sequence
+
+=item I<qual>
+
+quality if the file is FASTQ
 
 =back
 
 =head2 getFastqRead()
 
-If the file is FASTQ, this method returns the same read object as I<getRead()> but with a faster parser. Attributes of the returned object:
-
-=over 4
-
-=item I<name>, header of the sequence (identifier)
-
-=item I<comment>, any string after the first whitespace in the header
-
-=item I<seq>, actual sequence
-
-=item I<qual>, quality if the file is FASTQ
-
-=back
+If the file is FASTQ, this method returns the same read object as I<getRead()> but with a faster parser.
+Attributes of the returned object are I<name>, I<comment>, I<seq>, I<qual> (as for I<getRead()>).
 
 =head2 getFileFormat(filename)
 
 This subroutine returns 'fasta', 'fastq' or <undef> for a given filepath (this is not a method of the instantiated object)
 
+=head1 ACKNOWLEDGEMENTS
+
+=over 4
+
+=item B<Heng Li's readfq()>
+
+This mnodule is a wrapper around the I<readfq()> subroutine originally written by Heng Li, that I adapted
+to retain I<sequence comments>.
+
+See: L<readfq repository|https://github.com/telatin/readfq>
+
+=back
+
+=head1 SEE ALSO
+
+=over 4
+
+=item L<BioX::Seq::Stream>
+
+A module to "parse FASTA and FASTQ files sequentially". This module was specifically designed to make the I<readfq()> subroutine portable,
+supporting several scripts making use of it, if a generic FASTA/FASTQ parses is needed Jeremy Volkening's C<BioX::Seq::Stream> is a well written alternative.
+
+=back
+
 =head1 CONTRIBUTORS
 
-Fabrizio Levorin has substantially contributed to the development of this module, and is a collaborator in the GitHub repository
+=over 4
+
+=item B<Fabrizio Levorin>
+
+has substantially contributed to the development of this module, and is a collaborator in the GitHub repository
+
+=back
 
 =head1 AUTHOR
 
